@@ -12,11 +12,11 @@ import textwrap
 import types
 import unittest
 
-# distutils imports `imp`, which triggers a DeprecationWarning starting with
+# setuptools imports `imp`, which triggers a DeprecationWarning starting with
 # Python 3.4 in the middle of my pristine test suite.  But if I do the import
 # upfront, there's no warning.  I cannot explain this, I'm just happy there's
 # no warning.
-import distutils  # noqa
+import setuptools  # noqa
 
 try:
     from unittest import mock
@@ -409,7 +409,7 @@ class StringRepresentationTest(GarbageCollectedMixin,
 
         self.assertRegex(
             objgraph._obj_label(x, shortnames=False),
-            'mymodule\.MyClass\\\\n<mymodule\.MyClass object at .*')
+            r'mymodule\.MyClass\\n<mymodule\.MyClass object at .*')
 
     def test_long_typename_with_no_module(self):
         x = type('MyClass', (), {'__module__': None})()
@@ -478,8 +478,6 @@ class StringRepresentationTest(GarbageCollectedMixin,
                                             (0.2, 0.3, 0.4), 0, 0))
 
     @skipIf(sys.version_info[0] > 2, "Python 3 has no unbound methods")
-    @skipIf(sys.version_info[:2] < (2, 6),
-            "Python 2.5 and older has no __func__")
     def test_edge_label_unbound_method(self):
         class MyClass(object):
             def a_method(self):
@@ -494,7 +492,7 @@ class StringRepresentationTest(GarbageCollectedMixin,
 
         self.assertRegex(
             objgraph._edge_label(d, 1, shortnames=False),
-            ' [label="mymodule\.MyClass\\n<mymodule\.MyClass object at .*"]')
+            r' [label="mymodule\.MyClass\n<mymodule\.MyClass object at .*"]')
 
     def test_short_repr_lambda(self):
         f = lambda x: x  # noqa
@@ -618,7 +616,7 @@ class RandomOutputChecker(doctest.OutputChecker):
 
 
 class IgnoreNodeCountChecker(RandomOutputChecker):
-    _r = re.compile('\(\d+ nodes\)$', re.MULTILINE)
+    _r = re.compile(r'\(\d+ nodes\)$', re.MULTILINE)
 
     def check_output(self, want, got, optionflags):
         if optionflags & NODES_VARY:
